[![Build Status][build-status-src]][build-status-href]
[![GitHub stars][github-stars-src]][github-stars-href]
[![GitHub license][github-license-src]][github-license-href]
[![GitHub issues][github-issues-src]][github-issues-href]

# Droptopus
![Droptopus Logo][droptopus-logo-src]

Droptopus is a drag'n'drop receiver, which routes dropped objects to the designated actions.

# Dependencies 
 - python3.5+
 - pyqt5

# Installation
 `pip3 install droptopus`

# Launch
 `python3 -m droptopus &`

## Acknowledgements

Droptopus uses

- [Nokia's][nokia-href]: [Qt][qt-href]

- [Riverbank Computing Limited's][riverbank-href]: [SIP][sip-href]

- [Riverbank Computing Limited's][riverbank-href]: [PyQt5][pyqt-href]

- [Icon8's][icons8-href]: [awesome icons][icons8-href]

Thanks!

## Sponsors

[![Become a sponsor][patreon-src]][patreon-href]

## License

This project is licensed under the MIT License - see the [LICENSE.md][github-license-href] file for details

[droptopus-logo-src]: https://raw.githubusercontent.com/ArtBIT/Droptopus/master/droptopus/assets/droptopus.png
[build-status-href]: https://travis-ci.org/ArtBIT/droptopus
[build-status-src]: https://travis-ci.org/ArtBIT/droptopus.svg
[github-issues-href]: https://github.com/ArtBIT/droptopus/issues
[github-issues-src]: https://img.shields.io/github/issues/ArtBIT/droptopus.svg
[github-license-href]: https://github.com/ArtBIT/Droptopus/blob/master/LICENSE.md
[github-license-src]: https://img.shields.io/github/license/ArtBIT/droptopus.svg
[github-stars-href]: https://github.com/ArtBIT/droptopus
[github-stars-src]: https://img.shields.io/github/stars/ArtBIT/droptopus.svg
[icons8-href]: http://icons8.com
[nokia-href]: http://www.nokia.com
[pyqt-href]: http://www.riverbankcomputing.co.uk/software/pyqt/intro
[qt-href]: http://qt.nokia.com
[riverbank-href]: http://www.riverbankcomputing.co.uk
[sip-href]: http://www.riverbankcomputing.co.uk/software/sip/intro
[patreon-src]: https://img.shields.io/badge/Patreon-Sponsor%20This-orange.svg
[patreon-href]: https://www.patreon.com/artbit
